Table with survival summary
tableSurvival(
x,
times = NULL,
timeScale = "days",
header = c("estimate"),
estimates = c("median_survival", "restricted_mean_survival"),
type = "gt",
groupColumn = NULL,
hide = c("result_id", "estimate_type"),
style = NULL,
.options = list()
)A tibble containing a summary of observed survival in the required units
Result from estimateSingleEventSurvival or estimateCompetingRiskSurvival
Times at which to report survival in the summary table
Time unit to report survival in: days, months or years
A vector specifying the elements to include in the header. The order of elements matters, with the first being the topmost header. Elements in header can be:
Any of the columns returned by tableColumns(result) to create a header
for these columns.
Any other input to create an overall header.
Character vector specifying which estimates to include in the table. Options include: "median_survival", "restricted_mean_survival", "q0_survival", "q05_survival", "q25_survival", "q75_survival", "q95_survival", "q100_survival". By default it includes c("median_survival", "restricted_mean_survival").
Character string specifying the desired output table format.
See tableType() for supported table types. If type = NULL, global
options (set via setGlobalTableOptions()) will be used if available;
otherwise, a default 'gt' table is created.
Columns to use as group labels, to see options use
tableColumns(result). By default, the name of the new group will be the
tidy* column names separated by ";". To specify a custom group name, use a
named list such as:
list("newGroupName" = c("variable_name", "variable_level")).
*tidy: The tidy format applied to column names replaces "_" with a space and
converts to sentence case. Use rename to customise specific column names.
Columns to drop from the output table. By default, result_id and
estimate_type are always dropped.
Defines the visual formatting of the table. This argument can be provided in one of the following ways:
Pre-defined style: Use the name of a built-in style (e.g., "darwin").
See tableStyle() for available options.
YAML file path: Provide the path to an existing .yml file defining
a new style.
List of custome R code: Supply a block of custom R code or a named list
describing styles for each table section. This code must be specific to
the selected table type.
If style = NULL, the function will use global options
(see setGlobalTableOptions()) or an existing _brand.yml file (if found);
otherwise, the default style is applied.
For more details, see the Styles vignette on the package website.
A named list with additional formatting options.
visOmopResults::tableOptions() shows allowed arguments and their default values.
# \donttest{
cdm <- mockMGUS2cdm()
surv <- estimateSingleEventSurvival(cdm,
targetCohortTable = "mgus_diagnosis",
outcomeCohortTable = "death_cohort")
tableSurvival(surv, times = c(50,100,365))
# }
Run the code above in your browser using DataLab